@@ -60,7 +60,7 @@ class KafkaConsumer(TriggerableEventBatchSource):
                  offset_reset_strategy: str = 'latest',
                  max_records: int = None,
                  timeout_ms: int = 0,
-                 empty_check_timeout_ms: int = 5000,
+                 # empty_check_timeout_ms: int = 5000,
                  **kwargs):
         super().__init__(**kwargs)
         self.topic = topic
@@ -69,8 +69,8 @@ class KafkaConsumer(TriggerableEventBatchSource):
         self.offset_reset_strategy = offset_reset_strategy
         self.max_records = max_records
         self.timeout_ms = timeout_ms
-        self.empty_check_timeout_s = empty_check_timeout_ms / 1000
-        self.last_empty_epoch: float = 0
+        # self.empty_check_timeout_s = empty_check_timeout_ms / 1000
+        # self.last_empty_epoch: float = 0
         self.inner_consumer: KC = KC(
             self.topic.topic_id,
             bootstrap_servers=[str(self.topic.server)],
@@ -81,8 +81,8 @@ class KafkaConsumer(TriggerableEventBatchSource):
         )
 
     def get_event_batch(self) -> List[Event]:
-        if time.time() < self.last_empty_epoch + self.empty_check_timeout_s:
-            return []
+        # if time.time() < self.last_empty_epoch + self.empty_check_timeout_s:
+        #     return []
         records: Dict = \
             self.inner_consumer.poll(timeout_ms=self.timeout_ms, max_records=self.max_records) \
                 if self.max_records is not None \
@@ -95,8 +95,8 @@ class KafkaConsumer(TriggerableEventBatchSource):
                     print(f'Invalid kafka message with type {str(type(event))}')  # TODO log
                 else:
                     record_list.append(event)
-        if len(record_list) == 0:
-            self.last_empty_epoch = time.time()
+        # if len(record_list) == 0:
+        #     self.last_empty_epoch = time.time()
         return record_list
 
 
