@@ -23,7 +23,7 @@ class PeriodicEventSource(TriggererEventSource):
         last_run: float = time.time()
         while self.consuming:
             try:
-                time.sleep(1)
+                time.sleep(0.1)
                 now = time.time()
                 if (last_run // self.sec_to_regenerate) != (now // self.sec_to_regenerate):
                     event: Event = self.generator_function()
